Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type LogConfig ¶ added in v0.2.0
type LogConfig struct {
Level LogLevel
ConsoleEnabled bool // is log to console
FileEnabled bool // is log to file
LogDir string
FileName string
MaxSize int // MaxSize the max size in MB of the logfile before it's rolled
MaxBackups int // MaxBackups the max number of rolled files to keep
MaxAge int // MaxAge the max age in days to keep a logfile
}
Click to show internal directories.
Click to hide internal directories.